# wdl_rf  
A two-stage algorithm WDL-RF allows end-to-end learning of prediction pipelines whose inputs are of arbitrary size, which contains the molecular fingerprint generation stage through a new weighted deep learning method and the bioactivity prediction stage by the random forest model.   

